==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ka_GE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "აქტივობა",
    "An error occurred while loading activities" : "აქტივობების ჩატვირთვისას წარმოიშვა შეცდომა",
    "No activity yet" : "ჯერ-ჯერობით აქტივობები არაა",
    "Load more activities" : "მეტი აქტივობის ჩატვირთვა",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არ არის მხარდაჭერილი!",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "{name} (invisible)" : "{name} (უჩინარი)",
    "{name} (restricted)" : "{name} (აკრძალული)",
    "Home" : "სახლი",
    "in {path}" : "{path}-ში",
    "This stream will show events like additions, changes & shares" : "ამ ნაკადში გამოჩნდება მოვლენების შესახებ ისეტი შეტყობინებები, როგორებიცაა დამატება, ცვლილება და გაზიარება",
    "There are no events for this filter" : "ამ ფილტრის შესაბამისი მოვლენები არაა",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "Open file" : "ფაილის გახსნა",
    "Personal activity feed for %s" : "პერსონალურ აქტივობათა ლენტი მომხმარებლისთვის %s",
    "Your feed URL is invalid" : "თქვენი ლენტის URL არასწორია",
    "Your settings have been updated." : "თქვენი პარამეტრები განახლდა.",
    "Settings have been updated." : "პარამეტრები განახლდა.",
    "All activities" : "ყველა აქტივობა",
    "By others" : "სხვების მიერ",
    "By you" : "თქვენს მიერ",
    "Activity notification for %s" : "აქტივობის შეტყობინება %s-თვის",
    "Hello %s" : "გამარჯობა, %s",
    "Hello %s," : "გამარჯობა, %s,",
    "There was some activity at %s" : "%s-ზე იყო გარკვეული აქტივობა",
    "_and %n more _::_and %n more _" : ["და კიდევ %n","და კიდევ %n"],
    "Mail" : "ფოსტა",
    "Stream" : "ნაკადი",
    "This application enables users to view actions related to their files in Nextcloud." : "ეს აპლიკაცია მომხმარებლებს აძლევს საშუალებას დაინახონ „Nextcloud“-ზე მათ ფაილებთან დაკავშირებული ქმედებები.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "ეს აპლიკაცია მომხმარებლებს აძლევს საშუალებას დაინახონ „Nextcloud“-ზე მათ ფაილებთან დაკავშირებული ქმედებები.\n\t\tგააქტირების შემთხვევაში მომხმარებლები დაინახავენ ახალ სიმბოლოს „აქტივობა“ თავიანთ აპლიკაციის მინიუში.\n\t\tდაჭერის შემთხვევაში მომხმარებლებისთვის გამოჩნდება ახალი გვერდი",
    "Activity feed" : "აქტივობათა ლენტი",
    "Send activity emails" : "აქტივობის ელ-წერილების გაგზავნა.",
    "Default settings" : "საწყისი პარამეტრები",
    "Configure the default activity settings for new users." : "საწყისი პარამეტრების კონფიგურირება ახალი მოხმარებლებისთვის.",
    "List your own actions in the stream" : "საკუთარი აქტივობების გამოჩენა ნაკადში",
    "Notify about your own actions via email" : "საკუთარ მოქმედებებზე შეტყობინებების ელ-ფოსტით მიღება",
    "You need to set up your email address before you can receive notification emails." : "ელ-ფოსტაზე შეტყობინების მიღებამდე, საჭიროა მიუთითოთ თქვენი მისამართი.",
    "Send emails:" : "ელ-წერილების გაგზავნა:",
    "As soon as possible" : "რაც შეიძლება მალე",
    "Hourly" : "საათობრივი",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "აირჩიეთ თუ რომელ აქტივობებზე გსურთ მიიღოთ ელ-შეტყობინება და რომელი მათგანი გამოჩნდეს აქტივობის აპლკაციის ნაკადში.",
    "Choose which activities you want to see in your stream." : "აირჩიეთ თუ რომელი აქტივობების ხილვა გსურთ თქვენს ნაკადში.",
    "Settings" : "პარამეტრები",
    "Enable RSS feed" : "RSS ლენტის გააქტიურება",
    "RSS feed" : "RSS ლენტა",
    "No more events to load" : "ყველა მოვლენა ჩამოტვირთულია"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-21.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ka_GE.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არ არის მხარდაჭერილი!",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "{name} (invisible)" : "{name} (უჩინარი)",
    "{name} (restricted)" : "{name} (აკრძალული)",
    "Home" : "სახლი",
    "in {path}" : "{path}-ში",
    "This stream will show events like additions, changes & shares" : "ამ ნაკადში გამოჩნდება მოვლენების შესახებ ისეტი შეტყობინებები, როგორებიცაა დამატება, ცვლილება და გაზიარება",
    "There are no events for this filter" : "ამ ფილტრის შესაბამისი მოვლენები არაა",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "Personal activity feed for %s" : "პერსონალურ აქტივობათა ლენტი მომხმარებლისთვის %s",
    "Your feed URL is invalid" : "თქვენი ლენტის URL არასწორია",
    "Your settings have been updated." : "თქვენი პარამეტრები განახლდა.",
    "Settings have been updated." : "პარამეტრები განახლდა.",
    "_and %n more _::_and %n more _" : ["და კიდევ %n","და კიდევ %n"],
    "All activities" : "ყველა აქტივობა",
    "By others" : "სხვების მიერ",
    "By you" : "თქვენს მიერ",
    "Activity notification for %s" : "აქტივობის შეტყობინება %s-თვის",
    "Hello %s" : "გამარჯობა, %s",
    "Hello %s," : "გამარჯობა, %s,",
    "There was some activity at %s" : "%s-ზე იყო გარკვეული აქტივობა",
    "Mail" : "ფოსტა",
    "Activity" : "აქტივობა",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "ეს აპლიკაცია მომხმარებლებს აძლევს საშუალებას დაინახონ „Nextcloud“-ზე მათ ფაილებთან დაკავშირებული ქმედებები.\n\t\tგააქტირების შემთხვევაში მომხმარებლები დაინახავენ ახალ სიმბოლოს „აქტივობა“ თავიანთ აპლიკაციის მინიუში.\n\t\tდაჭერის შემთხვევაში მომხმარებლებისთვის გამოჩნდება ახალი გვერდი",
    "No activity yet" : "ჯერ-ჯერობით აქტივობები არაა",
    "Activity feed" : "აქტივობათა ლენტი",
    "Notifications" : "შეტყობინებები",
    "Default settings" : "საწყისი პარამეტრები",
    "You need to set up your email address before you can receive notification emails." : "ელ-ფოსტაზე შეტყობინების მიღებამდე, საჭიროა მიუთითოთ თქვენი მისამართი.",
    "As soon as possible" : "რაც შეიძლება მალე",
    "Hourly" : "საათობრივი",
    "Daily" : "ყოველდღიური",
    "Weekly" : "ყოველკვირეული",
    "Settings" : "პარამეტრები",
    "Enable RSS feed" : "RSS ლენტის გააქტიურება",
    "RSS feed" : "RSS ლენტა",
    "No more events to load" : "ყველა მოვლენა ჩამოტვირთულია",
    "An error occurred while loading activities" : "აქტივობების ჩატვირთვისას წარმოიშვა შეცდომა",
    "Load more activities" : "მეტი აქტივობის ჩატვირთვა",
    "Open file" : "ფაილის გახსნა",
    "Stream" : "ნაკადი",
    "This application enables users to view actions related to their files in Nextcloud." : "ეს აპლიკაცია მომხმარებლებს აძლევს საშუალებას დაინახონ „Nextcloud“-ზე მათ ფაილებთან დაკავშირებული ქმედებები.",
    "Send activity emails" : "აქტივობის ელ-წერილების გაგზავნა.",
    "Configure the default activity settings for new users." : "საწყისი პარამეტრების კონფიგურირება ახალი მოხმარებლებისთვის.",
    "List your own actions in the stream" : "საკუთარი აქტივობების გამოჩენა ნაკადში",
    "Notify about your own actions via email" : "საკუთარ მოქმედებებზე შეტყობინებების ელ-ფოსტით მიღება",
    "Send emails:" : "ელ-წერილების გაგზავნა:",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "აირჩიეთ თუ რომელ აქტივობებზე გსურთ მიიღოთ ელ-შეტყობინება და რომელი მათგანი გამოჩნდეს აქტივობის აპლკაციის ნაკადში.",
    "Choose which activities you want to see in your stream." : "აირჩიეთ თუ რომელი აქტივობების ხილვა გსურთ თქვენს ნაკადში."
},
"nplurals=2; plural=(n!=1);");
